import { select,
         csv,
         scaleLinear,
         extent,
         min,
         max,
         axisLeft,
         axisBottom,
         format
       } from "d3"

const svg = select('svg');


const width = +svg.attr('width');
const height = +svg.attr("height");
const xLegend = 'Weight'
const yLegend = 'Horsepower'
const title = 'Horsepower by weight'

const render = data => {
  //   	 d.acceleration = +d.acceleration;
  //     d.cylinders = +d.cylinders;
  //     d.displacement = +d.displacement;
  //     d.horsepower = +d.horsepower;
  //     d.mpg = +d.mpg;
  //     d.weight = +d.weight;
  //     d.year = +d.year;

  const xValue = d => d.weight
  const yValue = d => d.horsepower
  const minAcceleration = min(data, d => d.acceleration)
  const maxAcceleration = max(data, d => d.acceleration)
  const accelerationDiff = maxAcceleration - minAcceleration
  const minRadius = 5
  const maxRadius = 20
  const radiusDiff = maxRadius - minRadius
  const radius = d =>
  	(d.acceleration - minAcceleration)/accelerationDiff*radiusDiff+minRadius
  
  const margin = { top:50,
                   right: 40,
                   bottom: 100,
                   left: 100
                 };
  const innerWidth = width - margin.left - margin.right
  const innerHeight = height - margin.top - margin.bottom
  
  
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([0, innerHeight])
  	.nice();
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);

  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(15);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10);
  
  const yAxisG = g.append('g')
    .call(yAxis);
  yAxisG.select('.domain').remove();
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  xAxisG.append('text')
  	.attr('class', 'xLegend')
    .text(xLegend)
  	.attr('fill', 'black')
  	.attr('x', `${innerWidth / 2}`)
  	.attr('y', `${50}`);
  
  yAxisG.append('text')
  	.attr('class', 'xLegend')
    .text(yLegend)
  	.attr('transform', 'rotate(-90)')
  	.attr('fill', 'black')
  	.attr('x', -innerHeight / 2)
  	.attr('text-anchor','middle')
  	.attr('y', -50);
  
  g.selectAll('circle').data(data)
  	.enter().append('circle')
  		.attr('cy', d => yScale(yValue(d)))
  		.attr('cx', d => xScale(xValue(d)))
  		.attr('r', d => radius(d));
  
  xAxisG.append('text')
  	.attr('class', 'title')
  	.attr('y', -innerHeight - 5)
  	.attr('x', `${innerWidth / 2}`)
  	.text(title);
};


csv('https://vizhub.com/curran/datasets/auto-mpg.csv')
  .then(data => {
    data.forEach(d => {
      d.acceleration = +d.acceleration;
      d.cylinders = +d.cylinders;
      d.displacement = +d.displacement;
      d.horsepower = +d.horsepower;
      d.mpg = +d.mpg;
      d.weight = +d.weight;
      d.year = +d.year;
    });
  console.log(data)
	render(data);
})